Crate allowthem_client

Crate allowthem_client 

allowthem-client: External-mode AuthClient that validates RS256 JWTs locally via JWKS and talks to the allowthem server for code exchange.

Structs

AuthorizeRequest
PKCE and state for an authorization request.
ExternalAuthClient
External-mode AuthClient that validates RS256 JWTs locally and talks to the allowthem server for code exchange.
ExternalAuthClientBuilder
Builder for constructing an ExternalAuthClient.
TokenExchangeResponse
Response from the token endpoint after authorization code exchange.