allowthem-client: External-mode AuthClient that validates RS256 JWTs locally via JWKS and talks to the allowthem server for code exchange.
Structs
- Authorize
Request - PKCE and state for an authorization request.
- External
Auth Client - External-mode AuthClient that validates RS256 JWTs locally and talks to the allowthem server for code exchange.
- External
Auth Client Builder - Builder for constructing an
ExternalAuthClient. - Token
Exchange Response - Response from the token endpoint after authorization code exchange.